@@ -44,7 +44,6 @@
 #' \code{\link[=changeproj,prevR-method]{changeproj}}, \code{\link{import.dhs}}.
 #' 
 #' @examples 
-#' \dontrun{
 #'  col <- c(id = "cluster",
 #'           x = "x",
 #'           y = "y",
@@ -58,7 +57,6 @@
 #'  
 #'  str(dhs)
 #'  print(dhs)
-#' }
 #' @keywords manip
 #' @export
 as.prevR = function(data, col,  boundary = NULL, proj = "+proj=longlat +ellps=WGS84"){
@@ -150,7 +148,7 @@ as.prevR = function(data, col,  boundary = NULL, proj = "+proj=longlat +ellps=WG
     proj = proj@projargs
   }
   isOk = try(CRS(proj),silent=T)
-  if(attr(isOk,"class") == "try-error"){
+  if(inherits(isOk,"try-error")){
     stop(gettextf("the projection %s, defined in the 'proj' argument, is incorect.",proj,domain="R-prevR"), call.=F)
   }
   projCRS = CRS(proj)
