@@ -26,10 +26,11 @@ setGeneric("export",
 #'   or if \code{format="shp"} or if \code{format="dbf"}).
 #' @param dec coerce the string to use for decimal point 
 #'   (unused if \code{element="boundary"} or if \code{format="shp"} or if \code{format="dbf"}).
-#' @param \dots additional arguments transmitted to \code{\link[maptools]{writePolyShape}}, 
-#'   \code{\link[maptools]{writePointsShape}}, \code{\link[foreign]{write.dbf}} or 
+#' @param \dots additional arguments transmitted to  
+#'   \code{\link[rgdal]{writeOGR}}, \code{\link[foreign]{write.dbf}} or 
 #'   \code{\link[utils]{write.table}}.
-#' 
+#' @importFrom foreign write.dbf
+#' @importFrom rgdal writeOGR
 #' @details If \code{element="boundary"}, the slot \code{boundary} of \code{object} 
 #' will be exported as a \emph{shapefile}.
 #' 
@@ -39,14 +40,14 @@ setGeneric("export",
 #' 
 #' \code{format} specifies the export format of the data frame returned by 
 #' \code{\link{as.data.frame.prevR}}: \tabular{ll}{
-#'     "shp" \tab Shape File (require packages \pkg{maptools} and \pkg{foreign})\cr
+#'     "shp" \tab Shape File (require the package \pkg{rgdal})\cr
 #'     "dbf" \tab DBASE format (extension: .dbf, require the package \pkg{foreign})\cr
 #'     "txt" \tab tabulated text (extension: .txt)\cr
 #'     "csv" \tab 'comma separated values' (extension: .csv)\cr
 #'     "csv2" \tab CSV variant using a semicolon as field separator (extension: .csv)
 #' }
-#' \code{ext} could be used to coerce the extension of the output filen except for 
-#' \emph{shapefile} export, which will write three different files (.shp, .shx et .dbf).
+#' \code{ext} could be used to coerce the extension of the output file, except for 
+#' \emph{shapefile} export, which will write four different files (.shp, .shx, .dbf and .prj).
 #' 
 #' The "txt" format uses by default a tabulation as field separator and a point "." for decimal point. 
 #' The "csv" format uses a comma "," as field separator and a point "." as decimal point.\cr
@@ -95,8 +96,8 @@ setMethod("export","prevR",
   #   ...  : permettent de passer tous les arguments des fonctions d'ecritures
   #    
   # Les fonctions d'ecriture appelees sont
-  #      writePolyShape pour l'ecriture de l'element boundary (package maptools)
-  #      writePointsShape pour l'ecriture de l'element cluster (package maptools)
+  #      writeOGR pour l'ecriture de l'element boundary (package rgdal)
+  #      writeOGR pour l'ecriture de l'element cluster (package rgdal)
   #      write.table
   #      write.dbf (package foreign)
   # 
@@ -117,8 +118,9 @@ setMethod("export","prevR",
         IDs <- sapply(slot(boundary, "polygons"), function(x) slot(x, "ID"))
         data <- data.frame(1, IDs,row.names=IDs)
         names(data) <- c("id", "name")
-        SPDF <- SpatialPolygonsDataFrame(boundary, data)
-        maptools::writePolyShape(SPDF, file, ...)
+        SPDF <- sp::SpatialPolygonsDataFrame(boundary, data)
+        #maptools::writePolyShape(SPDF, file, ...)
+        rgdal::writeOGR(SPDF, dirname(file), basename(file), driver="ESRI Shapefile", ...)
       }
       return(NULL)
     }
@@ -133,7 +135,8 @@ setMethod("export","prevR",
         PS = clusters
         coordinates(PS)= ~x+y
         PS@proj4string = object@proj
-        maptools::writePointsShape(PS,file, ...)
+        #maptools::writePointsShape(PS,file, ...)
+        rgdal::writeOGR(PS, dirname(file), basename(file), driver="ESRI Shapefile", ...)
       }
       if (is.null(ext) && format!='csv2') ext = format
       if (is.null(ext) && format=='csv2') ext = 'csv'
