@@ -19,6 +19,8 @@
 #' @param cex to control the text size on the graph
 #' @param progression show a progress bar?
 #' 
+#' @import ggplot2
+#' 
 #' @details 
 #' \code{N} determine the rings to use for the estimation.
 #' By default, a suggested value of N will be computed with \code{\link{Noptim}}.
@@ -75,15 +77,15 @@ quick.prevR <- function(object, N = Noptim(object), nb.cells = 100, cell.size =
     
     r$N <- factor(r$N, levels=N, labels=paste0("N=",N))
     
-    p <- ggplot(r, aes_string(x="x", y="y", fill="prev", z="radius")) +
-      geom_raster() +
-      scale_fill_gradientn(colours=prevR.colors.red(20)) +
-      stat_contour(aes_string(colour = "..level..")) +
-      scale_colour_continuous(low = "grey50", high = "grey50") +
-      facet_wrap(~ N) +
-      coord_fixed() + xlab("") + ylab("") +
-      labs(fill=legend.title) +
-      theme_prevR()
+    p <- ggplot2::ggplot(r, ggplot2::aes_string(x="x", y="y", fill="prev", z="radius")) +
+      ggplot2::geom_raster() +
+      ggplot2::scale_fill_gradientn(colours=prevR.colors.red(20)) +
+      ggplot2::stat_contour(aes_string(colour = "..level..")) +
+      ggplot2::scale_colour_continuous(low = "grey50", high = "grey50") +
+      ggplot2::facet_wrap(~ N) +
+      ggplot2::coord_fixed() + ggplot2::xlab("") + ggplot2::ylab("") +
+      ggplot2::labs(fill=legend.title) +
+      theme_prevR_light()
     
     p <- direct.label_prevR(p, list("top.pieces", cex=cex))
   }
@@ -91,9 +93,9 @@ quick.prevR <- function(object, N = Noptim(object), nb.cells = 100, cell.size =
   if (plot.results) print(p)
   
   if (return.results &!return.plot)
-    return(list(prev=prev, radius=radius))
+    return(list(prev=prev, radius=radius, tidy = r))
   else if (return.results & return.plot)
-    return(list(prev=prev, radius=radius, plot=p))
+    return(list(prev=prev, radius=radius, tidy = r, plot=p))
   else if (!return.results & return.plot)
-    return(list(plot=p))
+    return(list(tidy = r, plot=p))
 }
\ No newline at end of file
